@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.001-15-g67f9fe8
+package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.002-16-g55913a8
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One OpenAPI v3.1 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -20,6 +20,7 @@ use Safe::Isa;
 use File::ShareDir 'dist_dir';
 use Path::Tiny;
 use List::Util 'any';
+use MooX::TypeTiny 0.002002;
 use Types::Standard 'InstanceOf';
 use namespace::clean;
 
@@ -164,7 +165,7 @@ sub _traverse_schema ($self, $schema, $state) {
   });
 
   push $state->{errors}->@*, $subschema_state->{errors}->@*;
-  return if @{$subschema_state->{errors}};
+  return if $subschema_state->{errors}->@*;
 
   push $state->{identifiers}->@*, $subschema_state->{identifiers}->@*;
 }
@@ -183,7 +184,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
